pub enum InitError {
UninitElements,
WrongVec,
OutOfOrder,
}Expand description
An error that can occur when returning a shard to a writer.
Variants
UninitElements
One or more elements weren’t initialised.
WrongVec
A shard was returned to a writer other than the one that created it.
OutOfOrder
Shards were returned out-of-order or a shard was missing.