VecWriter

Struct VecWriter 

pub struct VecWriter<'vec, T> { /* private fields */ }
Builds a Vec<T>, with each variable-sized chunk of the Vec being initialised separately, most likely from a separate thread.

Implementations

Source

impl<'vec, T> VecWriter<'vec, T>

pub fn new(storage: &'vec mut Vec<T>) -> Self

Creates a new writer that will write into the supplied Vec.

pub fn take_shard(&mut self, n: usize) -> Shard<'vec, T>

Takes the next n elements of the vector or panics if there is insufficient capacity.

pub fn try_take_shard( &mut self, n: usize, ) -> Result<Shard<'vec, T>, InsufficientCapacity>

Takes the next n elements of the vector or returns an error if there is insufficient capacity.

pub fn take_shards( &mut self, sizes: impl Iterator<Item = usize>, ) -> Vec<Shard<'vec, T>>

Takes shards with sizes supplied by sizes. Panics if there is insufficient capacity.

pub fn try_take_shards( &mut self, sizes: impl Iterator<Item = usize>, ) -> Result<Vec<Shard<'vec, T>>, InsufficientCapacity>

pub fn return_shard(&mut self, shard: Shard<'_, T>)

Returns a shard to the vector, increasing the initialised length of the vector by the size of the shard. The shard must have been fully initialised before being returned. Shards must be returned in order. Panics on failure.

pub fn try_return_shard(&mut self, shard: Shard<'_, T>) -> Result<(), InitError>

As for return_shard, but returns an error on failure rather than panicking.

pub fn return_shards(&mut self, shards: Vec<Shard<'_, T>>)

Returns the supplied shards. Panics if any shards have not been fully initialised or if the shards are out-of-order.

pub fn try_return_shards( &mut self, shards: Vec<Shard<'_, T>>, ) -> Result<(), InitError>

Returns the supplied shards.